/////////////////////////////////////
// I2C.cpp
// 720020-1174x
//
// Applied Data Systems
// www.applieddata.net
//
// { See I2C.h for a description and history }
/////////////////////////////////////

#include "I2C.h"

I2C::I2C(BYTE busAddress)
{
	DEBUGMSG(TRUE, (_T("+I2C::I2C(0x%02x)\r\n"), busAddress));

	m_i2c = CreateFile(_T("IIC1:"), 
						 GENERIC_READ|GENERIC_WRITE, 
						 0, 
						 NULL,
						 OPEN_EXISTING,
						 0, 
						 NULL);

	if(m_i2c == INVALID_HANDLE_VALUE)
	{
		m_i2c = NULL;
		RETAILMSG(TRUE, (_T("Can't open 'IIC1:' driver: error %i\r\n"), GetLastError()));
		delete this;
		return;
	}

	// save the address, making sure the direction bit is off
	m_busAddress = busAddress & ~1;

	DEBUGMSG(TRUE, (_T("-I2C::I2C\r\n")));
}

I2C::~I2C()
{
	DEBUGMSG(TRUE, (_T("+I2C::~I2C\r\n")));

	if(m_i2c != NULL)
		CloseHandle(m_i2c);

	m_busAddress = 0x00;

	DEBUGMSG(TRUE, (_T("-I2C::~I2C\r\n")));
}

BOOL I2C::Write(BYTE *data, INT dataLength, BOOL setStart, BOOL setStop)
{
	DEBUGMSG(TRUE, (_T("+I2C::Write\r\n")));
	IIC_MESSAGE		message;
	DWORD			xfer;

	if((m_i2c == INVALID_HANDLE_VALUE) || (m_i2c == NULL))
		return FALSE;

	message.pData = data;

	message.bCreateStart = setStart ? 1 : 0;
	message.bCreateStop	 = setStop ? 1 : 0;
	message.uDataLength	 = dataLength;

	// send the command
	BOOL ret = WriteFile(m_i2c, &message, 3, &xfer, NULL);

	DEBUGMSG(TRUE, (_T("-I2C::Write\r\n")));

	return ret;
}

BOOL I2C::Read(BYTE *data, INT dataLength, BOOL setStart, BOOL setStop)
{
	DEBUGMSG(TRUE, (_T("+I2C::Read\r\n")));
	IIC_MESSAGE		message;
	DWORD			xfer;

	if((m_i2c == INVALID_HANDLE_VALUE) || (m_i2c == NULL))
		return FALSE;

	message.pData = data;

	message.bCreateStart = setStart ? 1 : 0;
	message.bCreateStop	 = setStop ? 1 : 0;
	message.uDataLength	 = dataLength;

	// read the config data
	BOOL ret = ReadFile(m_i2c, &message, 2, &xfer, NULL);

	DEBUGMSG(TRUE, (_T("-I2C::Read\r\n")));

	return ret;
}
